## Product details

The Shark StainStriker is a highly effective portable cleaner designed to tackle even the toughest spots and stains with ease. This advanced carpet and upholstery cleaner features a dual-activated formula coupled with ultra-powerful suction to effortlessly remove embedded stains, making it perfect for homes with pets or children. Its lightweight and compact design allows for easy maneuverability around the home, ensuring thorough cleaning of car interiors, upholstery, and carpets. Included are the Shark StainStriker, Mini Stain Eliminator, 3.5" Stain Eliminator Tool, a 6oz bottle of Deep Clean Pro Formula, and a 12oz bottle of OXY Multiplier Formula, offering a complete cleaning solution for various surfaces.
POWERFUL TOUGH STAIN ELIMINATION: Sharks dual-activated solution automatically mixes inside the handheld spot & stain remover to deliver 20x more stain-striking power.*
PERFECT FOR PETS: Instantly & permanently removes stubborn, lingering odors even pet urine and smoke.^
ULTRA-POWERFUL SUCTION: Pulls out embedded spots and stains to deliver like-new results.
WHOLE HOME CLEANING: Designed to remove spots and stains from carpets, area rugs, upholstery, car interiors, and more.
LIGHTWEIGHT & COMPACT DESIGN: At under 9lbs, tackle stains whenever and wherever they happen and conveniently store away when finished.
WHAT'S INCLUDED: Shark StainStriker,Shark StainStriker, Integrated Crevice Tool, 3.5" Reversible Bristle Tool, 6oz. Deep Clean Pro Formula, 12oz. OXY Multiplier Formula.
*vs Shark Deep Clean Pro Formula , ^when using Shark cleaning solution.
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Recommended surface
Carpet
Detergent tank capacity
0.5 gal
Cord length
12 ft
Weight
8.51 lb
More details
## Directions

Instructions
See User Manual
## Warranty

Warranty information
Five (5) Year Limited Warranty
Warranty url
https://support.sharkclean.com/hc/en-us/article_attachments/10001430828188
Ingredients

Ingredients
See Bottle
